@@ -44,22 +44,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 static void
 e_content_editor_default_init (EContentEditorInterface *iface)
 {
-	/**
-	 * EContentEditor:is-malfunction
-	 *
-	 * Determines whether the composer is malfunction. If it does, then
-	 * the result of calling functions like get_content() is undefined.
-	 */
-	g_object_interface_install_property (
-		iface,
-		g_param_spec_boolean (
-			"is-malfunction",
-			"Is Malfunction",
-			NULL,
-			FALSE,
-			G_PARAM_READABLE |
-			G_PARAM_STATIC_STRINGS));
-
 	/**
 	 * EContentEditor:can-copy
 	 *
@@ -610,18 +594,6 @@ e_content_editor_ref_spell_checker (EContentEditor *editor)
 	return spell_checker;
 }
 
-gboolean
-e_content_editor_is_malfunction (EContentEditor *editor)
-{
-	gboolean value = FALSE;
-
-	g_return_val_if_fail (E_IS_CONTENT_EDITOR (editor), FALSE);
-
-	g_object_get (G_OBJECT (editor), "is-malfunction", &value, NULL);
-
-	return value;
-}
-
 gboolean
 e_content_editor_can_cut (EContentEditor *editor)
 {
