@@ -742,27 +742,22 @@ em_utils_selection_set_uidlist (GtkSelectionData *selection_data,
 }
 
 /**
- * em_utils_selection_uidlist_foreach_sync:
- * @selection_data: a #GtkSelectionData with x-uid-list content
+ * em_utils_selection_get_uidlist:
+ * @data: selection data
  * @session: an #EMailSession
- * @func: a function to call for each UID and its folder
- * @user_data: user data for @func
- * @cancellable: optional #GCancellable object, or %NULL
- * @error: return location for a #GError, or %NULL
+ * @move: do we delete the messages.
  *
- * Calls @func for each folder and UID provided in @selection_data.
+ * Convert a uid list into a copy/move operation.
  *
  * Warning: Could take some time to run.
- *
- * Since: 3.26.3
  **/
 void
-em_utils_selection_uidlist_foreach_sync (GtkSelectionData *selection_data,
-					 EMailSession *session,
-					 EMUtilsUIDListFunc func,
-					 gpointer user_data,
-					 GCancellable *cancellable,
-					 GError **error)
+em_utils_selection_get_uidlist (GtkSelectionData *selection_data,
+                                EMailSession *session,
+                                CamelFolder *dest,
+                                gint move,
+                                GCancellable *cancellable,
+                                GError **error)
 {
 	/* format: "uri1\0uid1\0uri2\0uid2\0...\0urin\0uidn\0" */
 	gchar *inptr, *inend;
@@ -773,12 +768,10 @@ em_utils_selection_uidlist_foreach_sync (GtkSelectionData *selection_data,
 	GHashTable *uids_by_uri;
 	GHashTableIter iter;
 	gpointer key, value;
-	gboolean can_continue = TRUE;
 	GError *local_error = NULL;
 
 	g_return_if_fail (selection_data != NULL);
 	g_return_if_fail (E_IS_MAIL_SESSION (session));
-	g_return_if_fail (func != NULL);
 
 	data = gtk_selection_data_get_data (selection_data);
 	length = gtk_selection_data_get_length (selection_data);
@@ -830,12 +823,14 @@ em_utils_selection_uidlist_foreach_sync (GtkSelectionData *selection_data,
 		const gchar *uri = key;
 		GPtrArray *uids = value;
 
-		if (!local_error && can_continue) {
+		if (!local_error) {
 			/* FIXME e_mail_session_uri_to_folder_sync() may block. */
 			folder = e_mail_session_uri_to_folder_sync (
 				session, uri, 0, cancellable, &local_error);
 			if (folder) {
-				can_continue = func (folder, uids, user_data, cancellable, &local_error);
+				/* FIXME camel_folder_transfer_messages_to_sync() may block. */
+				camel_folder_transfer_messages_to_sync (
+					folder, uids, dest, move, NULL, cancellable, &local_error);
 				g_object_unref (folder);
 			}
 		}
@@ -850,55 +845,6 @@ em_utils_selection_uidlist_foreach_sync (GtkSelectionData *selection_data,
 		g_propagate_error (error, local_error);
 }
 
-struct UIDListData {
-	CamelFolder *dest;
-	gboolean move;
-};
-
-static gboolean
-uidlist_move_uids_cb (CamelFolder *folder,
-		      const GPtrArray *uids,
-		      gpointer user_data,
-		      GCancellable *cancellable,
-		      GError **error)
-{
-	struct UIDListData *uld = user_data;
-
-	g_return_val_if_fail (uld != NULL, FALSE);
-
-	/* FIXME camel_folder_transfer_messages_to_sync() may block. */
-	return camel_folder_transfer_messages_to_sync (
-		folder, (GPtrArray *) uids, uld->dest, uld->move, NULL, cancellable, error);
-}
-
-/**
- * em_utils_selection_get_uidlist:
- * @data: selection data
- * @session: an #EMailSession
- * @move: do we delete the messages.
- *
- * Convert a uid list into a copy/move operation.
- *
- * Warning: Could take some time to run.
- **/
-void
-em_utils_selection_get_uidlist (GtkSelectionData *selection_data,
-                                EMailSession *session,
-                                CamelFolder *dest,
-                                gint move,
-                                GCancellable *cancellable,
-                                GError **error)
-{
-	struct UIDListData uld;
-
-	g_return_if_fail (CAMEL_IS_FOLDER (dest));
-
-	uld.dest = dest;
-	uld.move = move;
-
-	em_utils_selection_uidlist_foreach_sync	(selection_data, session, uidlist_move_uids_cb, &uld, cancellable, error);
-}
-
 /**
  * em_utils_build_export_basename:
  * @folder: a #CamelFolder where the message belongs
@@ -1519,6 +1465,7 @@ em_utils_is_re_in_subject (const gchar *subject,
 {
 	gchar **prefixes_strv;
 	gchar **separators_strv;
+	const gchar *localized_re, *localized_separator;
 	gboolean res;
 	gint ii;
 
@@ -1552,6 +1499,33 @@ em_utils_is_re_in_subject (const gchar *subject,
 		return TRUE;
 	}
 
+	/* Translators: This is a reply attribution in the message reply subject. Both 'Re'-s in the 'reply-attribution' translation context should translate into the same string. */
+	localized_re = C_("reply-attribution", "Re");
+
+	/* Translators: This is a reply attribution separator in the message reply subject. This should match the ':' in 'Re: %s' in the 'reply-attribution' translation context. */
+	localized_separator = C_("reply-attribution", ":");
+
+	if (check_prefix (subject, localized_re, (const gchar * const *) separators_strv, skip_len)) {
+		if (!use_separators_strv)
+			g_strfreev (separators_strv);
+
+		return TRUE;
+	}
+
+	if (localized_separator && g_strcmp0 (localized_separator, ":") != 0) {
+		const gchar *localized_separator_strv[2];
+
+		localized_separator_strv[0] = localized_separator;
+		localized_separator_strv[1] = NULL;
+
+		if (check_prefix (subject, localized_re, (const gchar * const *) localized_separator_strv, skip_len)) {
+			if (!use_separators_strv)
+				g_strfreev (separators_strv);
+
+			return TRUE;
+		}
+	}
+
 	if (use_prefixes_strv) {
 		prefixes_strv = (gchar **) use_prefixes_strv;
 	} else {
