@@ -402,9 +402,7 @@ day_second_zone_clicked (GtkWidget *widget,
 	gtk_widget_show_all (menu);
 
 	gtk_menu_attach_to_widget (GTK_MENU (menu), widget, NULL);
-	gtk_menu_popup (
-		GTK_MENU (menu), NULL, NULL, NULL, NULL,
-		0, gtk_get_current_event_time ());
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
 }
 
 static void
@@ -717,6 +715,7 @@ calendar_preferences_construct (ECalendarPreferences *prefs,
 	ECalConfigTargetPrefs *target;
 	GSettings *settings;
 	GSettings *eds_settings;
+	GSettings *mail_settings;
 	gboolean locale_supports_12_hour_format;
 	gint i;
 	GtkWidget *toplevel;
@@ -725,6 +724,7 @@ calendar_preferences_construct (ECalendarPreferences *prefs,
 	GSList *l;
 
 	settings = e_util_ref_settings ("org.gnome.evolution.calendar");
+	mail_settings = e_util_ref_settings ("org.gnome.evolution.mail");
 
 	locale_supports_12_hour_format =
 		calendar_config_locale_supports_12_hour_format ();
@@ -987,6 +987,12 @@ calendar_preferences_construct (ECalendarPreferences *prefs,
 		widget, "active",
 		G_SETTINGS_BIND_DEFAULT);
 
+	widget = e_builder_get_widget (prefs->priv->builder, "week_view_days_left_to_right");
+	g_settings_bind (
+		settings, "week-view-days-left-to-right",
+		widget, "active",
+		G_SETTINGS_BIND_DEFAULT);
+
 	widget = e_builder_get_widget (prefs->priv->builder, "tasks_due_today_highlight");
 	g_settings_bind (
 		settings, "task-due-today-highlight",
@@ -1055,6 +1061,12 @@ calendar_preferences_construct (ECalendarPreferences *prefs,
 		widget, "sensitive",
 		G_SETTINGS_BIND_GET);
 
+	widget = e_builder_get_widget (prefs->priv->builder, "to_do_bar_show_no_duedate_tasks");
+	g_settings_bind (
+		mail_settings, "to-do-bar-show-no-duedate-tasks",
+		widget, "active",
+		G_SETTINGS_BIND_DEFAULT);
+
 	/* Alarms tab */
 	widget = e_builder_get_widget (prefs->priv->builder, "notify_with_tray");
 	g_settings_bind (
@@ -1113,6 +1125,7 @@ calendar_preferences_construct (ECalendarPreferences *prefs,
 	/* FIXME: weakref? */
 	setup_changes (prefs);
 
+	g_object_unref (mail_settings);
 	g_object_unref (settings);
 }
 
