@@ -53,7 +53,8 @@ enum {
 	PROP_MAIL_VIEW,
 	PROP_REPLY_STYLE,
 	PROP_MARK_SEEN_ALWAYS,
-	PROP_TO_DO_PANE
+	PROP_TO_DO_PANE,
+	PROP_DELETE_SELECTS_PREVIOUS
 };
 
 /* Forward Declarations */
@@ -104,39 +105,6 @@ reconnect_folder_loaded_event (EMailReader *child,
 	g_signal_emit_by_name (parent, "folder-loaded");
 }
 
-/* To recognize old values from new values */
-#define PROPORTION_LOWER_LIMIT 1000000
-
-static gboolean
-mail_shell_content_map_setting_to_proportion_cb (GValue *value,
-						 GVariant *variant,
-						 gpointer user_data)
-{
-	gint stored;
-	gdouble proportion = 0.15;
-
-	stored = g_variant_get_int32 (variant);
-
-	if (stored >= PROPORTION_LOWER_LIMIT)
-		proportion = (stored - PROPORTION_LOWER_LIMIT) / ((gdouble) PROPORTION_LOWER_LIMIT);
-
-	g_value_set_double (value, proportion);
-
-	return TRUE;
-}
-
-static GVariant *
-mail_shell_content_map_proportion_to_setting_cb (const GValue *value,
-						 const GVariantType *expected_type,
-						 gpointer user_data)
-{
-	gdouble proportion;
-
-	proportion = g_value_get_double (value);
-
-	return g_variant_new_int32 (PROPORTION_LOWER_LIMIT + (gint32) (proportion * PROPORTION_LOWER_LIMIT));
-}
-
 static void
 mail_shell_content_set_property (GObject *object,
                                  guint property_id,
@@ -167,6 +135,12 @@ mail_shell_content_set_property (GObject *object,
 				E_MAIL_READER (object),
 				g_value_get_boolean (value));
 			return;
+
+		case PROP_DELETE_SELECTS_PREVIOUS:
+			e_mail_reader_set_delete_selects_previous (
+				E_MAIL_READER (object),
+				g_value_get_boolean (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -214,6 +188,12 @@ mail_shell_content_get_property (GObject *object,
 				value, e_mail_shell_content_get_to_do_pane (
 				E_MAIL_SHELL_CONTENT (object)));
 			return;
+
+		case PROP_DELETE_SELECTS_PREVIOUS:
+			g_value_set_boolean (
+				value, e_mail_reader_get_delete_selects_previous (
+				E_MAIL_READER (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -259,8 +239,7 @@ mail_shell_content_constructed (GObject *object)
 
 	/* Build content widgets. */
 
-	widget = e_paned_new (GTK_ORIENTATION_HORIZONTAL);
-	e_paned_set_fixed_resize (E_PANED (widget), FALSE);
+	widget = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_container_add (GTK_CONTAINER (shell_content), widget);
 	gtk_widget_show (widget);
 
@@ -305,21 +284,15 @@ mail_shell_content_constructed (GObject *object)
 	settings = e_util_ref_settings ("org.gnome.evolution.mail");
 
 	if (e_shell_window_is_main_instance (e_shell_view_get_shell_window (shell_view))) {
-		g_settings_bind_with_mapping (
+		g_settings_bind (
 			settings, "to-do-bar-width",
-			paned, "proportion",
-			G_SETTINGS_BIND_DEFAULT,
-			mail_shell_content_map_setting_to_proportion_cb,
-			mail_shell_content_map_proportion_to_setting_cb,
-			NULL, NULL);
+			paned, "position",
+			G_SETTINGS_BIND_DEFAULT);
 	} else {
-		g_settings_bind_with_mapping (
+		g_settings_bind (
 			settings, "to-do-bar-width-sub",
-			paned, "proportion",
-			G_SETTINGS_BIND_DEFAULT,
-			mail_shell_content_map_setting_to_proportion_cb,
-			mail_shell_content_map_proportion_to_setting_cb,
-			NULL, NULL);
+			paned, "position",
+			G_SETTINGS_BIND_DEFAULT);
 	}
 
 	g_settings_bind (
@@ -327,6 +300,11 @@ mail_shell_content_constructed (GObject *object)
 		priv->to_do_pane, "show-completed-tasks",
 		G_SETTINGS_BIND_DEFAULT);
 
+	g_settings_bind (
+		settings, "to-do-bar-show-no-duedate-tasks",
+		priv->to_do_pane, "show-no-duedate-tasks",
+		G_SETTINGS_BIND_DEFAULT);
+
 	g_object_unref (settings);
 
 	window = e_mail_reader_get_window (E_MAIL_READER (object));
@@ -575,6 +553,12 @@ e_mail_shell_content_class_init (EMailShellContentClass *class)
 		PROP_MARK_SEEN_ALWAYS,
 		"mark-seen-always");
 
+	/* Inherited from EMailReader */
+	g_object_class_override_property (
+		object_class,
+		PROP_DELETE_SELECTS_PREVIOUS,
+		"delete-selects-previous");
+
 	g_object_class_install_property (
 		object_class,
 		PROP_TO_DO_PANE,
