@@ -1192,6 +1192,12 @@ em_composer_prefs_construct (EMComposerPrefs *prefs,
 		widget, "active",
 		G_SETTINGS_BIND_DEFAULT);
 
+	widget = e_builder_get_widget (prefs->builder, "chkUseLocalizedFwdRe");
+	g_settings_bind (
+		settings, "composer-use-localized-fwd-re",
+		widget, "active",
+		G_SETTINGS_BIND_DEFAULT);
+
 	widget = e_builder_get_widget (prefs->builder, "chkReplyStartBottom");
 	g_settings_bind (
 		settings, "composer-reply-start-bottom",
@@ -1260,6 +1266,12 @@ em_composer_prefs_construct (EMComposerPrefs *prefs,
 		widget, "active",
 		G_SETTINGS_BIND_DEFAULT);
 
+	widget = e_builder_get_widget (prefs->builder, "chkSignatureInNewOnly");
+	g_settings_bind (
+		settings, "composer-signature-in-new-only",
+		widget, "active",
+		G_SETTINGS_BIND_DEFAULT);
+
 	widget = e_builder_get_widget (prefs->builder, "chkTopSignature");
 	g_settings_bind (
 		settings, "composer-top-signature",
