@@ -1907,8 +1907,6 @@ e_shell_view_show_popup_menu (EShellView *shell_view,
 {
 	EShellWindow *shell_window;
 	GtkWidget *menu;
-	guint event_button = 0;
-	guint32 event_time;
 
 	g_return_val_if_fail (E_IS_SHELL_VIEW (shell_view), NULL);
 
@@ -1918,21 +1916,12 @@ e_shell_view_show_popup_menu (EShellView *shell_view,
 	menu = e_shell_window_get_managed_widget (shell_window, widget_path);
 	g_return_val_if_fail (GTK_IS_MENU (menu), NULL);
 
-	if (button_event != NULL) {
-		gdk_event_get_button (button_event, &event_button);
-		event_time = gdk_event_get_time (button_event);
-	} else {
-		event_time = gtk_get_current_event_time ();
-	}
-
 	if (!gtk_menu_get_attach_widget (GTK_MENU (menu)))
 		gtk_menu_attach_to_widget (GTK_MENU (menu),
 					   GTK_WIDGET (shell_window),
 					   NULL);
-	gtk_menu_popup (
-		GTK_MENU (menu),
-		NULL, NULL, NULL, NULL,
-		event_button, event_time);
+
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), button_event);
 
 	return menu;
 }
